@@ -10,8 +10,9 @@
 ##' @param n number of matrices to sample
 ##' @param bootstrap whether to sample participants and contacts randomly using a bootstrap; by default, will use bootstrap if n > 1
 ##' @param counts whether to return counts (instead of means)
-##' @param symmetric whether to make matrix symmetric
+##' @param symmetric whether to make matrix symmetric, such that c_{ij}N_i = c{ji}N_j.
 ##' @param split whether to split the number of contacts and assortativity
+##' @param estimated.participant.age if set to "mean" (default), people whose ages are given as a range (in columns named "..._est_min" and "..._est_max") but not exactly (in a column named "..._exact") will have their age set to the mid-point of the range; if set to "sample", the age will be sampled from the range; if set to "missing", age ranges will be treated as missing
 ##' @param estimated.contact.age if set to "mean" (default), people whose ages are given as a range (in columns named "..._est_min" and "..._est_max") but not exactly (in a column named "..._exact") will have their age set to the mid-point of the range; if set to "sample", the age will be sampled from the range; if set to "missing", age ranges will be treated as missing
 ##' @param missing.participant.age if set to "remove" (default), participants without age information are removed; if set to "keep", participants with missing age are kept and treated as a separate age group
 ##' @param missing.contact.age if set to "remove" (default), participants that that have contacts without age information are removed; if set to "sample", contacts without age information are sampled from all the contacts of participants of the same age group; if set to "keep", contacts with missing age are kept and treated as a separate age group
@@ -30,7 +31,7 @@
 ##' data(polymod)
 ##' contact_matrix(polymod, countries = "United Kingdom", age.limits = c(0, 1, 5, 15))
 ##' @author Sebastian Funk
-contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter, n = 1, bootstrap, counts = FALSE, symmetric = FALSE, split = FALSE, estimated.contact.age=c("mean", "sample", "missing"), missing.participant.age = c("remove", "keep"), missing.contact.age = c("remove", "sample", "keep"), weights = c(), weigh.dayofweek = FALSE, sample.all.age.groups = FALSE, quiet = FALSE, ...)
+contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter, n = 1, bootstrap, counts = FALSE, symmetric = FALSE, split = FALSE, estimated.participant.age=c("mean", "sample", "missing"), estimated.contact.age=c("mean", "sample", "missing"), missing.participant.age = c("remove", "keep"), missing.contact.age = c("remove", "sample", "keep"), weights = c(), weigh.dayofweek = FALSE, sample.all.age.groups = FALSE, quiet = FALSE, ...)
 {
     ## circumvent R CMD CHECK errors by defining global variables
     lower.age.limit <- NULL
@@ -48,43 +49,45 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
     sampled.weight <- NULL
     bootstrap.weight <- NULL
     participants <- NULL
-
+    sum_weight <- NULL
+    
     surveys <- c("participants", "contacts")
-
+    
     dot.args <- list(...)
     unknown.args <- setdiff(names(dot.args), union(names(formals(check.survey)), names(formals(pop_age))))
     if (length(unknown.args) > 0)
     {
         stop("Unknown argument(s): ", paste(unknown.args, sep=", "), ".")
     }
-
+    
     ## record if 'missing.participant.age' and 'missing.contact.age' are set, for later
     missing.participant.age.set <- !missing(missing.participant.age)
     missing.contact.age.set <- !missing(missing.contact.age)
-
+    
     ## read arguments
+    estimated.participant.age <- match.arg(estimated.participant.age)
     estimated.contact.age <- match.arg(estimated.contact.age)
     missing.participant.age <- match.arg(missing.participant.age)
     missing.contact.age <- match.arg(missing.contact.age)
-
+    
     ## get the survey
     survey <- get_survey(survey, quiet)
     ## check and get columns
     columns <- check(survey, columns=TRUE, quiet=TRUE, ...)
-
+    
     ## if bootstrap not asked for
     if (missing(bootstrap)) bootstrap <- (n > 1)
-
+    
     ## check if specific countries are requested (if a survey contains data from multiple countries)
     if (length(countries) > 0 && columns[["country"]] %in% colnames(survey$participants))
     {
         survey$participants[, paste(columns[["country"]]) :=
-                                  countrycode(get(columns[["country"]]),
-                                              "country.name", "country.name")]
+                                countrycode(get(columns[["country"]]),
+                                            "country.name", "country.name")]
         if (all(nchar(countries) == 2))
         {
             suppressWarnings(corrected_countries <-
-                                     countrycode(countries, "iso2c", "country.name"))
+                                 countrycode(countries, "iso2c", "country.name"))
         } else
         {
             suppressWarnings(corrected_countries <-
@@ -103,9 +106,37 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             stop("No participants left after selecting countries.")
         }
     }
-
+    
     ## check maximum participant age in the data
-    max.age <- max(survey$participants[, get(columns[["participant.age"]])], na.rm = TRUE) + 1
+    part_min.column <- paste(columns[["participant.age"]], "est_min", sep="_")
+    part_max.column <- paste(columns[["participant.age"]], "est_max", sep="_")
+    
+    if (!(columns[["participant.age"]] %in% colnames(survey$participants)))
+    {
+        survey$participants[, paste(columns[["participant.age"]]) := NA_integer_]
+    }
+    
+    if (!(part_max.column %in% colnames(survey$participants)) &
+        (columns[["participant.age"]] %in% colnames(survey$participants)) 
+    )
+    {
+        max.age <- max(survey$participants[, get(columns[["participant.age"]])], na.rm = TRUE) +  1
+        
+    } else if (part_max.column %in% colnames(survey$participants) &
+               (columns[["participant.age"]] %in% colnames(survey$participants))) 
+    {
+        max.age <- max(
+            c(
+                survey$participants[, get(columns[["participant.age"]])],
+                survey$participants[, get(part_max.column)]
+            ),
+            na.rm = TRUE
+        ) + 1
+    } else if(part_max.column %in% colnames(survey$participants)){
+        max.age <- max(survey$participants[, get(columns[["participant.age"]])], na.rm = TRUE) +  1
+        
+    }
+    
     if (missing(age.limits))
     {
         all.ages <-
@@ -119,7 +150,7 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
     {
         stop("'age.limits' must be an increasing integer vector of lower age limits.")
     }
-
+    
     ## check if any filters have been requested
     if (!missing(filter)) {
         missing_columns <- list()
@@ -144,7 +175,31 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             warning("filter column(s) ", paste(missing_all), " not found")
         }
     }
-
+    
+    ## sample estimated participant ages
+    if (part_min.column %in% colnames(survey$participants) &&
+        part_max.column %in% colnames(survey$participants))
+    {
+        if (estimated.participant.age == "mean")
+        {
+            survey$participants[is.na(get(columns[["participant.age"]])) &
+                                    !is.na(get(part_min.column)) & !is.na(get(part_max.column)),
+                                paste(columns[["participant.age"]]) :=
+                                    as.integer(rowMeans(.SD)),
+                                .SDcols=c(part_min.column, part_max.column)]
+        } else if (estimated.participant.age == "sample")
+        {
+            survey$participants[is.na(get(columns[["participant.age"]])) &
+                                    !is.na(get(part_min.column)) & !is.na(get(part_max.column)) &
+                                    get(part_min.column) <= get(part_max.column),
+                                paste(columns[["participant.age"]]) :=
+                                    as.integer(runif(.N,
+                                                     get(part_min.column),
+                                                     get(part_max.column)))]
+        }
+    }
+    
+    
     if (missing.participant.age == "remove" &&
         nrow(survey$participants[is.na(get(columns[["participant.age"]])) |
                                  get(columns[["participant.age"]]) <  min(age.limits)]) > 0)
@@ -156,25 +211,25 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         }
         survey$participants <-
             survey$participants[!is.na(get(columns[["participant.age"]])) &
-                                get(columns[["participant.age"]]) >=  min(age.limits)]
+                                    get(columns[["participant.age"]]) >=  min(age.limits)]
     }
-
+    
     exact.column <- paste(columns[["contact.age"]], "exact", sep="_")
     min.column <- paste(columns[["contact.age"]], "est_min", sep="_")
     max.column <- paste(columns[["contact.age"]], "est_max", sep="_")
-
+    
     ## set contact age if it's not in the data
     if (!(columns[["contact.age"]] %in% colnames(survey$contacts)))
     {
         survey$contacts[, paste(columns[["contact.age"]]) := NA_integer_]
-
+        
         if (exact.column %in% colnames(survey$contacts))
         {
             survey$contacts[!is.na(get(exact.column)),
                             paste(columns[["contact.age"]]) := get(exact.column)]
         }
     }
-
+    
     ## convert factors to integers
     for (age_column in
          c(columns[["contact.age"]], min.column, max.column, exact.column)) {
@@ -182,10 +237,10 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             class(survey$contacts[[age_column]]) == "factor")
         {
             survey$contacts[, paste(age_column) :=
-                                  as.integer(levels(get(age_column)))[get(age_column)]]
+                                as.integer(levels(get(age_column)))[get(age_column)]]
         }
     }
-
+    
     ## sample estimated contact ages
     if (min.column %in% colnames(survey$contacts) &&
         max.column %in% colnames(survey$contacts))
@@ -193,22 +248,22 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         if (estimated.contact.age == "mean")
         {
             survey$contacts[is.na(get(columns[["contact.age"]])) &
-                            !is.na(get(min.column)) & !is.na(get(max.column)),
+                                !is.na(get(min.column)) & !is.na(get(max.column)),
                             paste(columns[["contact.age"]]) :=
                                 as.integer(rowMeans(.SD)),
                             .SDcols=c(min.column, max.column)]
         } else if (estimated.contact.age == "sample")
         {
             survey$contacts[is.na(get(columns[["contact.age"]])) &
-                            !is.na(get(min.column)) & !is.na(get(max.column)) &
-                            get(min.column) <= get(max.column),
+                                !is.na(get(min.column)) & !is.na(get(max.column)) &
+                                get(min.column) <= get(max.column),
                             paste(columns[["contact.age"]]) :=
                                 as.integer(runif(.N,
                                                  get(min.column),
                                                  get(max.column)))]
         }
     }
-
+    
     if (missing.contact.age == "remove" &&
         nrow(survey$contacts[is.na(get(columns[["contact.age"]])) |
                              get(columns[["contact.age"]]) < min(age.limits)]) > 0)
@@ -220,11 +275,11 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         }
         missing.age.id <-
             survey$contacts[is.na(get(columns[["contact.age"]])) |
-                            get(columns[["contact.age"]]) < min(age.limits),
+                                get(columns[["contact.age"]]) < min(age.limits),
                             get(columns[["id"]])]
         survey$participants <- survey$participants[!(get(columns[["id"]]) %in% missing.age.id)]
     }
-
+    
     ## if split or symmetric requested, get demographic data (survey population)
     need.survey.pop <- split || symmetric
     if (need.survey.pop)
@@ -258,11 +313,11 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     survey.representative=TRUE
                 }
             }
-
+            
             if (!survey.representative) {
                 ## get population data for countries from 'wpp' package
                 country.pop <- data.table(wpp_age(survey.countries))
-
+                
                 ## check if survey data are from a specific year - in that case
                 ## use demographic data from that year, otherwise latest
                 if (columns[["year"]] %in% colnames(survey$participants))
@@ -275,16 +330,16 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     warning("No '", columns[["year"]], "' column found in the data. Will use ",
                             survey.year, " population data.")
                 }
-
+                
                 ## check if any survey countries are not in wpp
                 missing.countries <- setdiff(survey.countries, unique(country.pop$country))
                 if (length(missing.countries) > 0)
                 {
                     stop("Could not find population data for ",
-                            paste(missing.countries, collapse = ", "), ". ",
-                            " Use wpp_countries() to get a list of country names.")
+                         paste(missing.countries, collapse = ", "), ". ",
+                         " Use wpp_countries() to get a list of country names.")
                 }
-
+                
                 ## get demographic data closest to survey year
                 country.pop.year <- unique(country.pop[, year])
                 survey.year <-
@@ -293,12 +348,12 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     country.pop[year == survey.year][, list(population = sum(population)),
                                                      by = "lower.age.limit"]
             }
-
+            
             if (survey.representative) {
                 survey.pop <-
                     survey$participants[, lower.age.limit :=
-                                              reduce_agegroups(get(columns[["participant.age"]]),
-                                                               age.limits)]
+                                            reduce_agegroups(get(columns[["participant.age"]]),
+                                                             age.limits)]
                 survey.pop <- survey.pop[, list(population=.N), by=lower.age.limit]
                 survey.pop <- survey.pop[!is.na(lower.age.limit)]
                 if (columns[["year"]] %in% colnames(survey$participants))
@@ -311,22 +366,22 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         ## adjust age groups by interpolating, in case they don't match between
         ## demographic and survey data
         survey.pop <- data.table(pop_age(survey.pop, age.limits, ...))
-
+        
         ## possibly adjust age groups according to maximum age (so as not to have empty age groups)
         survey.pop[, lower.age.limit := reduce_agegroups(lower.age.limit, age.limits)]
         survey.pop <- survey.pop[, list(population = sum(population)), by=lower.age.limit]
         setkey(survey.pop, lower.age.limit)
         ## re-assign lower age limits in participants
         survey$participants[, lower.age.limit :=
-                                  reduce_agegroups(get(columns[["participant.age"]]),
-                                                   survey.pop$lower.age.limit)]
+                                reduce_agegroups(get(columns[["participant.age"]]),
+                                                 survey.pop$lower.age.limit)]
         present.lower.age.limits <- unique(survey.pop$lower.age.limit)
         present.lower.age.limits <-
             present.lower.age.limits[order(present.lower.age.limits)]
-
+        
         ## set upper age limits
         survey.pop[, upper.age.limit := c(survey.pop$lower.age.limit[-1], max.age)]
-
+        
         lower.upper.age.limits <-
             data.table(lower.age.limit = present.lower.age.limits,
                        upper.age.limit = c(present.lower.age.limits[-1], max.age))
@@ -334,22 +389,23 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         survey$participants <-
             merge(survey$participants, lower.upper.age.limits, by="lower.age.limit", all.x=TRUE)
     }
-
+    
     survey$participants[, lower.age.limit := reduce_agegroups(get(columns[["participant.age"]]),
                                                               age.limits[age.limits < max.age])]
-    part.age.group.breaks <- c(age.limits[age.limits < max.age], max.age)
+    part.age.group.breaks <- c(age.limits[age.limits <= max.age], max.age + 1)
     survey$participants[, age.group :=
-                              cut(survey$participants[, get(columns[["participant.age"]])],
-                                  breaks = part.age.group.breaks,
-                                  right = FALSE)]
+                            cut(survey$participants[, get(columns[["participant.age"]])],
+                                breaks = part.age.group.breaks,
+                                right = FALSE)]
     age.groups <- survey$participants[, levels(age.group)]
     age.groups[length(age.groups)] <-
-        paste0(max(survey$participants$lower.age.limit, na.rm=TRUE), "+")
+        sub("\\[([0-9]+),.*$", "\\1+", age.groups[length(age.groups)])
     survey$participants[, age.group :=
-                              factor(age.group, levels=levels(age.group), labels=age.groups)]
-
+                            factor(age.group, levels=levels(age.group), labels=age.groups)]
+    
     survey$participants[, weight := 1]
     survey$contacts[, weight := 1]
+    
     ## assign weights to participants, to account for weekend/weekday variation
     if (weigh.dayofweek) {
         found.dayofweek <- FALSE
@@ -357,8 +413,16 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         {
             if ("dayofweek" %in% colnames(survey[[table]]))
             {
-                survey[[table]][dayofweek %in% 1:5, weight := 5]
-                survey[[table]][!(dayofweek %in% 1:5), weight := 2]
+                ## Add column sum_weight: Number of entries on weekdays / weekends
+                survey[[table]][,  sum_weight := nrow(.SD), 
+                                by = (dayofweek %in% 1:5), ]
+                
+                ## The sum of the weights on weekdays is 5
+                survey[[table]][dayofweek %in% 1:5, weight := 5/sum_weight]
+                ## The sum of the weights on weekend is 2
+                survey[[table]][!(dayofweek %in% 1:5), weight := 2/sum_weight]
+                
+                survey[[table]][,  sum_weight := NULL]
                 found.dayofweek <- TRUE
             }
         }
@@ -368,19 +432,25 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     "Will ignore.")
         }
     }
-
+    
     ## further weigh contacts if columns are specified
     if (length(weights) > 0) {
         for (i in 1:length(weights)) {
             for (table in surveys) {
                 if (weights[i] %in% colnames(survey[[table]]))
                 {
-                    survey[[table]][, weight := weight * get(weights[i])]
+                    ## Number of entry per level of weight[i]
+                    survey[[table]][,  sum_weight := nrow(.SD), 
+                                    by = get(weights[i])]
+                    ## Compute the individual weight
+                    survey[[table]][,  weight := weight * get(weights[i]) / sum_weight]
+                    ## Remove the column "sum_weight"
+                    survey[[table]][,  sum_weight := NULL]
                 }
             }
         }
     }
-
+    
     if (n > 1)
     {
         if (!bootstrap)
@@ -389,19 +459,19 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             n <- 1
         }
     }
-
+    
     ## merge participants and contacts into a single data table
     survey$participants[, weight := weight / sum(weight) * .N]
     setkeyv(survey$participants, columns[["id"]])
     participant_ids <- unique(survey$participants[[columns[["id"]]]])
-
+    
     survey$contacts <-
         merge(survey$contacts, survey$participants, by = columns[["id"]], all = F,
               allow.cartesian = T, suffixes=c(".cont", ".part"))
     survey$contacts[, weight := weight.cont * weight.part]
     survey$contacts[, weight := weight / sum(weight) * .N]
     setkeyv(survey$contacts, columns[["id"]])
-
+    
     ## sample contacts
     if (missing.contact.age == "sample" &&
         nrow(survey$contacts[is.na(get(columns[["contact.age"]]))]) > 0)
@@ -415,13 +485,13 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             {
                 ## some contacts in the age group have an age, sample from these
                 survey$contacts[is.na(get(columns[["contact.age"]])) &
-                         age.group == this.age.group,
-                         paste(columns[["contact.age"]]) :=
-                             sample(survey$contacts[!is.na(get(columns[["contact.age"]])) &
-                                             age.group == this.age.group,
-                                             get(columns[["contact.age"]])],
-                                    size = .N,
-                                    replace = TRUE)]
+                                    age.group == this.age.group,
+                                paste(columns[["contact.age"]]) :=
+                                    sample(survey$contacts[!is.na(get(columns[["contact.age"]])) &
+                                                               age.group == this.age.group,
+                                                           get(columns[["contact.age"]])],
+                                           size = .N,
+                                           replace = TRUE)]
             } else {
                 ## no contacts in the age group have an age, sample uniformly between limits
                 min.contact.age <-
@@ -429,28 +499,28 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                 max.contact.age <-
                     survey$contacts[, max(get(columns[["contact.age"]]), na.rm=TRUE)]
                 survey$contacts[is.na(get(columns[["contact.age"]])) &
-                         age.group == this.age.group,
-                         paste(columns[["contact.age"]]) :=
-                             as.integer(floor(runif(.N, min = min.contact.age,
-                                                    max = max.contact.age + 1)))]
+                                    age.group == this.age.group,
+                                paste(columns[["contact.age"]]) :=
+                                    as.integer(floor(runif(.N, min = min.contact.age,
+                                                           max = max.contact.age + 1)))]
             }
         }
     }
-
+    
     ## set contact age groups
     max.contact.age <-
         survey$contacts[, max(get(columns[["contact.age"]]), na.rm = TRUE) + 1]
-
+    
     contact.age.group.breaks <- part.age.group.breaks
     if (max.contact.age > max(contact.age.group.breaks)) {
         contact.age.group.breaks[length(contact.age.group.breaks)] <- max.contact.age
     }
     survey$contacts[, contact.age.group :=
-                          cut(get(columns[["contact.age"]]),
-                              breaks = contact.age.group.breaks,
-                              labels = age.groups,
-                              right = FALSE)]
-
+                        cut(get(columns[["contact.age"]]),
+                            breaks = contact.age.group.breaks,
+                            labels = age.groups,
+                            right = FALSE)]
+    
     ret <- list()
     for (i in seq_len(n))
     {
@@ -465,17 +535,17 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                                                lower.age.limit])
                 good.sample <- !sample.all.age.groups ||
                     (length(setdiff(age.limits, part.age.limits)) == 0)
-
+                
                 sample.table <-
                     data.table(id=part.sample, weight=1)
                 sample.table <-
                     sample.table[, list(bootstrap.weight=sum(weight)), by=id]
                 setnames(sample.table, "id", columns[["id"]])
                 setkeyv(sample.table, columns[["id"]])
-
+                
                 sampled.contacts <- merge(survey$contacts, sample.table)
                 sampled.contacts[, sampled.weight := weight * bootstrap.weight]
-
+                
                 sampled.participants <-
                     merge(survey$participants, sample.table)
                 sampled.participants[, sampled.weight := weight * bootstrap.weight]
@@ -488,22 +558,22 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             sampled.participants <- survey$participants
             sampled.participants[, sampled.weight := weight]
         }
-
+        
         ## calculate weighted contact matrix
         weighted.matrix <-
             xtabs(data = sampled.contacts,
                   formula = sampled.weight ~ age.group + contact.age.group,
                   addNA = TRUE)
-
+        
         dims <- dim(weighted.matrix)
         dim.names <- dimnames(weighted.matrix)
-
+        
         if (!counts) { ## normalise to give mean number of contacts
             ## calculate normalisation vector
             norm.vector <-
                 xtabs(data = sampled.participants,
                       formula = sampled.weight ~ age.group, addNA = TRUE)
-
+            
             ## normalise contact matrix
             weighted.matrix <-
                 array(apply(weighted.matrix, 2, function(x) x/norm.vector), dim=dims,
@@ -511,13 +581,13 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             ## set non-existent data to NA
             weighted.matrix[is.nan(weighted.matrix)] <- NA_real_
         }
-
+        
         ## construct a warning in case there are NAs
         na.headers <- any(is.na(colnames(weighted.matrix))) ||
             any(is.na(rownames(weighted.matrix)))
         na.content <- any(is.na(weighted.matrix))
         na.present <- na.headers || na.content
-
+        
         if (na.present)
         {
             warning.suggestion <- "  Consider "
@@ -529,7 +599,7 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     suggested.options <- c(suggested.options, "'missing.participant.age'")
                 if (any(is.na(colnames(weighted.matrix))))
                     suggested.options <- c(suggested.options, "'missing.contact.age'")
-
+                
                 warning.suggestion <-
                     paste0(warning.suggestion, paste(suggested.options, collapse = " and "))
                 if (na.content)
@@ -539,14 +609,14 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                 {
                     warning.suggestion <- paste0(warning.suggestion, ".")
                 }
-
+                
             }
             if (na.content)
             {
                 warning.suggestion <- paste0(warning.suggestion, "adjusting the age limits.")
             }
         }
-
+        
         if (symmetric & prod(dim(as.matrix(weighted.matrix))) > 1) {
             if (counts) {
                 warning("'symmetric=TRUE' does not make sense with 'counts=TRUE'; ",
@@ -565,9 +635,9 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                     (normalised.weighted.matrix + t(normalised.weighted.matrix))
             }
         }
-
+        
         ret[[i]] <- list()
-
+        
         if (split)
         {
             if (counts)
@@ -586,7 +656,7 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
             {
                 ## get rid of name but preserve row and column names
                 weighted.matrix <- unname(weighted.matrix)
-
+                
                 nb.contacts <- apply(weighted.matrix, 1, sum)
                 mean.contacts <- sum(survey.pop$population*nb.contacts)/
                     sum(survey.pop$population)
@@ -595,7 +665,7 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                 spectrum <- as.numeric(eigen(spectrum.matrix, only.values = TRUE)$values[1])
                 ret[[i]][["mean.contacts"]] <- mean.contacts
                 ret[[i]][["normalisation"]] <- spectrum/mean.contacts
-
+                
                 age.proportions <- survey.pop$population / sum(survey.pop$population)
                 weighted.matrix <-
                     diag(1 / nb.contacts) %*% weighted.matrix %*% diag(1 / age.proportions)
@@ -603,10 +673,10 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
                 ret[[i]][["contacts"]] <- nb.contacts
             }
         }
-
+        
         ret[[i]][["matrix"]] <- weighted.matrix
     }
-
+    
     if (exists("survey.year")) {
         survey.pop[, year := survey.year]
         survey.pop <-
@@ -615,7 +685,7 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
         survey.pop <- survey.pop[, list(age.group, population,
                                         proportion=population/sum(population), year)]
     }
-
+    
     ## get number of participants in each age group
     if (any(is.na(survey$participants$age.group))) {
         useNA <- "always"
@@ -625,14 +695,14 @@ contact_matrix <- function(survey, countries=c(), survey.pop, age.limits, filter
     part.pop <- data.table(table(survey$participants[, age.group], useNA = useNA))
     setnames(part.pop, c("age.group", "participants"))
     part.pop[, proportion := participants / sum(participants)]
-
+    
     if (length(ret) > 1) return_value <- list(matrices = ret)
     else return_value <- ret[[1]]
-
+    
     if (!is.null(return_value)) {
         if (need.survey.pop) return_value[["demography"]] <- survey.pop[]
         return_value[["participants"]] <- part.pop[]
     }
-
+    
     return(return_value)
 }
