@@ -10,18 +10,17 @@
 limits_to_agegroups <- function(x, limits) {
     if (missing(limits)) limits <- unique(x)[order(unique(x))]
     limits <- limits[!is.na(limits)]
-    agegroups <- c()
-    if (length(limits) > 1) {
-        agegroups <- vapply(seq(1, length(limits) - 1), function(y) {
+    agegroups <- if (length(limits) > 1) {
+        vapply(seq(1, length(limits) - 1), function(y) {
             if ((limits[y+1] - 1) > limits[y]) {
                 paste(limits[y], limits[y+1] - 1, sep = "-")
             } else {
                 paste(limits[y])
             }
         }, "")
-    }
+    } else { c() }
     agegroups <- c(agegroups, paste(limits[length(limits)], "+", sep = ""))
-    agegroups <- factor(agegroups, levels = agegroups)
+    agegroups <- factor(agegroups, levels = agegroups, ordered = TRUE)
     names(agegroups) <- limits
     return(unname(agegroups[as.character(x)]))
 }
